# WARNING: Please don't edit this file. It was generated by Python/WinRT v3.2.1

import winrt.system
from winrt._winrt_windows_applicationmodel_holographic import (
    HolographicKeyboard,
)

__all__ = [
    "HolographicKeyboard",
]




# WARNING: Please don't edit this file. It was generated by Python/WinRT v3.2.1

import datetime
import sys
import types
import typing
import uuid as _uuid
from builtins import property as _property

import winrt._winrt
import winrt.system
import winrt.windows.foundation.numerics as windows_foundation_numerics
import winrt.windows.perception.spatial as windows_perception_spatial

Self = typing.TypeVar('Self')

@typing.final
class HolographicKeyboard_Static(winrt._winrt.IInspectable_Static):
    # Windows.ApplicationModel.Holographic.HolographicKeyboard Windows.ApplicationModel.Holographic.HolographicKeyboard::GetDefault()
    def get_default(cls) -> HolographicKeyboard: ...

@typing.final
class HolographicKeyboard(winrt.system.Object, metaclass=HolographicKeyboard_Static):
    # System.Void Windows.ApplicationModel.Holographic.HolographicKeyboard::ResetPlacementOverride()
    def reset_placement_override(self) -> None: ...
    # System.Void Windows.ApplicationModel.Holographic.HolographicKeyboard::SetPlacementOverride(Windows.Perception.Spatial.SpatialCoordinateSystem,Windows.Foundation.Numerics.Vector3,Windows.Foundation.Numerics.Quaternion)
    def set_placement_override(self, coordinate_system: windows_perception_spatial.SpatialCoordinateSystem, top_center_position: typing.Union[windows_foundation_numerics.Vector3, typing.Tuple[winrt.system.Single, winrt.system.Single, winrt.system.Single]], orientation: typing.Union[windows_foundation_numerics.Quaternion, typing.Tuple[winrt.system.Single, winrt.system.Single, winrt.system.Single, winrt.system.Single]], /) -> None: ...
    # System.Void Windows.ApplicationModel.Holographic.HolographicKeyboard::SetPlacementOverride(Windows.Perception.Spatial.SpatialCoordinateSystem,Windows.Foundation.Numerics.Vector3,Windows.Foundation.Numerics.Quaternion,Windows.Foundation.Numerics.Vector2)
    def set_placement_override_with_max_size(self, coordinate_system: windows_perception_spatial.SpatialCoordinateSystem, top_center_position: typing.Union[windows_foundation_numerics.Vector3, typing.Tuple[winrt.system.Single, winrt.system.Single, winrt.system.Single]], orientation: typing.Union[windows_foundation_numerics.Quaternion, typing.Tuple[winrt.system.Single, winrt.system.Single, winrt.system.Single, winrt.system.Single]], max_size: typing.Union[windows_foundation_numerics.Vector2, typing.Tuple[winrt.system.Single, winrt.system.Single]], /) -> None: ...

